@@ -484,7 +484,7 @@ class AbsoluteDifferenceReason:
     Assign doubt when the absolute difference between label and regression is too large.
 
     Arguments:
-        model: scikit-learn outlier model
+        model: scikit-learn regression model
         threshold: cutoff for doubt assignment
 
     Usage:
@@ -511,8 +511,27 @@ class AbsoluteDifferenceReason:
         self.threshold = threshold
 
     def __call__(self, X, y):
-        difference = np.abs(self.model.predict(X) - y)
-        return (difference >= self.threshold).astype(np.float16)
+        pred = self.model.predict(X)
+        return self.from_predict(pred, y, self.threshold)
+
+    @staticmethod
+    def from_predict(pred, y, threshold):
+        """
+        Outputs a reason array from a prediction array, skipping the need for a model.
+
+        Usage:
+        ```python
+        import numpy as np
+        from doubtlab.reason import AbsoluteDifferenceReason
+
+        y = np.random.randn(100)
+        preds = np.random.randn(100)
+
+        predicate = AbsoluteDifferenceReason.from_predict(preds, y, threshold=0.1)
+        ```
+        """
+        difference = np.abs(pred - y)
+        return (difference >= threshold).astype(np.float16)
 
 
 class RelativeDifferenceReason:
@@ -520,7 +539,7 @@ class RelativeDifferenceReason:
     Assign doubt when the relative difference between label and regression is too large.
 
     Arguments:
-        model: scikit-learn outlier model
+        model: scikit-learn regression model
         threshold: cutoff for doubt assignment
 
     Usage:
@@ -547,8 +566,31 @@ class RelativeDifferenceReason:
         self.threshold = threshold
 
     def __call__(self, X, y):
-        difference = np.abs(self.model.predict(X) - y) / y
-        return (difference >= self.threshold).astype(np.float16)
+        pred = self.model.predict(X)
+        return self.from_predict(pred, y, threshold=self.threshold)
+
+    @staticmethod
+    def from_predict(pred, y, threshold):
+        """
+        Outputs a reason array from a prediction array, skipping the need for a model.
+
+        Usage:
+        ```python
+        import numpy as np
+        from doubtlab.reason import RelativeDifferenceReason
+
+        y = np.random.randn(100)
+        preds = np.random.randn(100)
+
+        predicate = RelativeDifferenceReason.from_predict(preds, y, threshold=0.1)
+        ```
+        """
+        if np.any(y == 0.0):
+            raise ValueError(
+                "Your `y` values contain 0. Will cause divided by zero error."
+            )
+        difference = np.abs(pred - y) / y
+        return (difference >= threshold).astype(np.float16)
 
 
 class CleanlabReason:
@@ -611,3 +653,60 @@ class CleanlabReason:
     def __call__(self, X, y):
         probas = self.model.predict_proba(X)
         return self.from_proba(probas, y, self.min_doubt, self.sorted_index_method)
+
+
+class StandardizedErrorReason:
+    """
+    Assign doubt when the absolute standardized residual is too high.
+
+    Arguments:
+        model: scikit-learn regression model
+        threshold: cutoff for doubt assignment
+
+    Usage:
+
+    ```python
+    from sklearn.datasets import load_diabetes
+    from sklearn.linear_model import LinearRegression
+
+    from doubtlab.ensemble import DoubtEnsemble
+    from doubtlab.reason import StandardizedErrorReason
+
+    X, y = load_diabetes(return_X_y=True)
+    model = LinearRegression()
+    model.fit(X, y)
+
+    doubt = DoubtEnsemble(reason = StandardizedErrorReason(model, threshold=2.))
+    indices = doubt.get_indices(X, y)
+    ```
+    """
+
+    def __init__(self, model, threshold=2.0):
+        if threshold <= 0:
+            raise ValueError("threshold value should be positive")
+        self.model = model
+        self.threshold = threshold
+
+    def __call__(self, X, y):
+        preds = self.model.predict(X)
+        return self.from_predict(preds, y, self.threshold)
+
+    @staticmethod
+    def from_predict(pred, y, threshold):
+        """
+        Outputs a reason array from a prediction array, skipping the need for a model.
+
+        Usage:
+        ```python
+        import numpy as np
+        from doubtlab.reason import StandardizedErrorReason
+
+        y = np.random.randn(100)
+        preds = np.random.randn(100)
+
+        predicate = StandardizedErrorReason.from_predict(preds, y, threshold=0.1)
+        ```
+        """
+        res = y - pred
+        res_std = res / np.std(res, ddof=1)
+        return (np.abs(res_std) >= threshold).astype(np.float16)
